<?php
	/** This script handles any feedback that is submitted by the Mobile App user through their phone.
	 * It expects a POST request to be made to /mobile/feedback/index.php with the following parameters:
	 * feedback[message] = <The message that the user entered> *Required
	 * feedback[email] = <The user's email> (Optional) but you will get an error if the email is invalid.
	 * feedback[subject] = <The category of the user's submission> (Optional)
	 * Response: The response is always in the form of JSON.
	 * 	Success: A successful response will contain a JSON field called "success" with a friendly message.
	 * 	Failure: A failed response will contain a JSON field called "errors" with a list of errors that were found.
	 *
	 * Sample Query String: feedback[message]=asdfasdf&feedback[email]=1234@gmail.com&feedback[subject]=yousuck
	 * Sample Response: {"success":"Your message was submitted successfully"}
	 */

   include('../include/config.php');
   include('../include/database.php');
	include('helpers.php');

	$_POST = $_GET;

	$rv = array();

	//validate request
	if(!isset($_POST['feedback']))
	{
		$rv['errors'] = array();
		$rv['errors'][] = 'This form only accepts POST requests. Go away.';
	}

	$feedback_arr = @$_POST['feedback'];
   $feedback_arr = json_decode($feedback_arr, true);

	//Message is required.
	if(!isset($feedback_arr['message']) || !$feedback_arr['message'])
	{
		$rv['errors'][] = 'Please enter a message.';			
	}

	$email = isset($feedback_arr['email']) ? $feedback_arr['email'] : '';

	//validate email
	if($email && !is_valid_email($email))
	{
		$rv['errors'][] = 'The email you entered is invalid.';
	}

	//If there are any errors, die.
	if(isset($rv['errors']))
	{
		die(json_encode($rv));
	}

	$message = $feedback_arr['message'];	
	$subject = isset($feedback_arr['subject']) ? $feedback_arr['subject'] : '';

	db_query('INSERT INTO feedback (subject, email, message) VALUES("%s", "%s", "%s")', $subject, $email, $message);

	//Let's not print out errors if we got this far.
	unset($rv['errors']);
	$rv['success'] = 'Your message was submitted successfully';

	echo json_encode($rv);

?>
